
.. raw:: html

    <style media="screen" type="text/css">
      h1 { display:none; }
      th { display:none; }
    </style>

*******
SNCosmo
*******


.. image:: _static/sncosmo_banner_96.png
    :width: 409px
    :height: 96px



SNCosmo at a glance
===================

SNCosmo is a Python library for high-level supernova cosmology
analysis. It aims to make such analysis both as flexible and clear as
possible. It is built on NumPy, SciPy and AstroPy.

.. toctree::
   :maxdepth: 1

   whatsnew
   about
   install
   contributing

* Check out the source code: https://github.com/sncosmo/sncosmo
* Report bugs, request features: https://github.com/sncosmo/sncosmo/issues
* User & developer mailing list: https://groups.google.com/forum/#!forum/sncosmo

Usage
=====

.. toctree::
   :maxdepth: 1

   models
   bandpasses
   magsystems
   photdata
   fitting
   cuts
   simulation
   registry
   configuration
   reference
